selects two variables from a long format Quitte and puts them into a wide format Quitte
Source:R/prepQuitteForScatter.R
prepQuitteForScatter.RdQuitteIn contains two variables containedin varNames that should be plotted in a scatter plot. The functions forms the new QuitteOut with the variables x and y. QuitteOut can be used in ggplot with plotting x and y. The unit needs to be replaced by None.
Examples
if (FALSE) { # \dontrun{
quitteOut <- prepQuitteForScatter(quitteIn, c('Emissions|CO2', 'Price|Carbon'))
} # }