quitte example data with three models (REMIND, GCAM, MESSAGEix) and two scenarios (Current Policies, Delayed transition)
Source:R/quitte_example_dataAR6.R
quitte_example_dataAR6.RdA quitte object with some example data from NGFS Phase 3.
R/quitte_example_dataAR6.R
quitte_example_dataAR6.RdA quitte object with some example data from NGFS Phase 3.