Skip to content

Changes the identifier for the global region to "World".

Usage

useWorld(qu)

Arguments

qu

A quitte object with a global region.

Value

The quitte object with the global region named "World".

Author

Patrick Rein