R/unique_or_levels.R
unique_or_levels.Rd
Abstract the differences between character vectors and factors.
unique_or_levels(x)
A character vector or a factor.
A character vector with the unique elements of x if it is a character vector, or the levels of x if it is a factor.
x
Michaja Pehl