R/useWorld.R
useWorld.Rd
Changes the identifier for the global region to "World".
useWorld(qu)
A quitte object with a global region.
The quitte object with the global region named "World".
Patrick Rein